<?php
require_once("../../classes/class.users.php");
require_once("../../classes/class.validation.php");
require_once("../../classes/class.date_processing.php");
require_once("../../classes/class.authentication.php");
require_once("../../includes/global_defaults.inc.php");

//1. RECHECK IF THE USER IS VALID //
try
{
	$AuthObject = new ApplicationAuthentication;
	$LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
	header('location:unauthorized_login_admin.php');
	exit;
}
catch (Exception $e)
{
	header('location:unauthorized_login_admin.php');
	exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_ADD_STOCK_RETURN) !== true)
{
	header('location:/admin/unauthorized_login_admin.php');
	exit;
}

require_once("../../classes/inventory_management/class.product_categories.php");
require_once("../../classes/inventory_management/class.products.php");
require_once("../../classes/inventory_management/class.departments.php");
require_once("../../classes/school_administration/class.branch_staff.php");
require_once("../../classes/inventory_management/class.stock_issue.php");
require_once("../../classes/inventory_management/class.stock_return.php");

$StaffCategoryList = array('Teaching' => 'Teaching Staff', 'NonTeaching' => 'Non Teaching Staff');

$IssueTypeList = array('Staff' => 'Staff', 'Department' => 'Department');

$AllBranchStaffList = array();
$AllBranchStaffList = BranchStaff::GetActiveBranchStaff('Teaching');

$AllProductCategoryList = array();
$AllProductCategoryList = ProductCategory::GetActiveProductCategories();

$AllProductList = array();
$AllProductList = Product::GetProductsByProductCategoryID(key($AllProductCategoryList));

$AllDepartmentList = array();
$AllDepartmentList = Department::GetActiveDepartments();

$InputErrors = array();

$HasErrors = false;

$Clean = array();
$Clean['Process'] = 0;

$Clean['IssueType'] = 'Staff';
$Clean['DepartmentID'] = 0;

$Clean['StaffCategory'] = '';
$Clean['BranchStaffID'] = 0;

$Clean['ProductVendorID'] = '';
$Clean['Description'] = '';

$Clean['StockReturnDetailsRow'] = array();

if (isset($_POST['hdnProcess']))
{
	$Clean['Process'] = (int) $_POST['hdnProcess'];
}

switch ($Clean['Process'])
{
	case 1: #Return Stock Save Case
		if (isset($_POST['IssueType']))
		{
			$Clean['IssueType'] = strip_tags(trim($_POST['IssueType']));
		}

		if (isset($_POST['DepartmentID']))
		{
			$Clean['DepartmentID'] = (int) $_POST['DepartmentID'];
		}

		if (isset($_POST['BranchStaffID']))
		{
			$Clean['BranchStaffID'] = (int) $_POST['BranchStaffID'];
		}	

		if (isset($_POST['StockReturnDetailsRow']))
        {
            $Clean['StockReturnDetailsRow'] = $_POST['StockReturnDetailsRow'];
        }

        if (count($Clean['StockReturnDetailsRow']) <= 0)
        {
            $RecordValidator->AttachTextError('Unknown error, please try again.');
        }

        $NewStockReturn = new StockReturn();

        $NewStockReturn->SetIssueType($Clean['IssueType']);
		$NewStockReturn->SetDepartmentID($Clean['DepartmentID']);
		$NewStockReturn->SetBranchStaffID($Clean['BranchStaffID']);
		$NewStockReturn->SetStockReturnDetails($Clean['StockReturnDetailsRow']);

        $NewStockReturn->SetCreateUserID($LoggedUser->GetUserID());

        /*if ($NewStockReturn->RecordExists())
        {
            $NewRecordValidator->AttachTextError('...');
            $HasErrors = true;
            break;
        }*/

        if (!$NewStockReturn->Save())
        {
            $NewRecordValidator->AttachTextError(ProcessErrors($NewStockReturn->GetLastErrorCode()));
            $HasErrors = true;
            break;
        }

        header('location:stock_return_list.php?POMode=RA');
        exit;
    break;

	case 7: #Search Case	
		if (isset($_POST['drdIssueType']))
		{
			$Clean['IssueType'] = strip_tags(trim($_POST['drdIssueType']));
		}

		if (isset($_POST['drdDepartment']))
		{
			$Clean['DepartmentID'] = (int) $_POST['drdDepartment'];
		}

		if (isset($_POST['drdStaffCategory']))
		{
			$Clean['StaffCategory'] = strip_tags(trim($_POST['drdStaffCategory']));
		}

		if (isset($_POST['drdBranchStaff']))
		{
			$Clean['BranchStaffID'] = (int) $_POST['drdBranchStaff'];
		}
		
		$NewRecordValidator = new Validator();

		$AllBranchStaffList = BranchStaff::GetActiveBranchStaff($Clean['StaffCategory']);
		
		$NewRecordValidator->ValidateInSelect($Clean['StaffCategory'], $StaffCategoryList, 'Unknown error, please try again.');
		$NewRecordValidator->ValidateInSelect($Clean['BranchStaffID'], $AllBranchStaffList, 'Unknown error, please try again.');

		/*$NewRecordValidator->ValidateInSelect($Clean['IssueType'], $IssueTypeList, 'Unknown error, please try again.1');

		if ($Clean['IssueType'] == 'Staff')
		{
			$NewRecordValidator->ValidateInSelect($Clean['StaffCategory'], $StaffCategoryList, 'Unknown error, please try again.');
			$NewRecordValidator->ValidateInSelect($Clean['BranchStaffID'], $AllBranchStaffList, 'Unknown error, please try again.');
		}

		if ($Clean['IssueType'] == 'Department')
		{
			$NewRecordValidator->ValidateInSelect($Clean['DepartmentID'], $AllDepartmentList, 'Unknown error, please try again.');			
		}*/

		if ($NewRecordValidator->HasNotifications())
		{
			$HasErrors = true;
			break;
		}

		$Filters['DepartmentID'] = $Clean['DepartmentID'];
		$Filters['IssueType'] = $Clean['IssueType'];
		$Filters['BranchStaffID'] = $Clean['BranchStaffID'];
		$Filters['StockReturn'] = 1;
		
		$AllIssuedStock = StockIssue::GetStockIssued($TotalRecords, true, $Filters);
	break;	
}

require_once('../html_header.php');
?>
<title>Add Stock Return</title>
<!-- DataTables CSS -->
<link href="/admin/vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">
<link href="/admin/vendor/datatables-plugins/dataTables.bootstrap.css" rel="stylesheet">

<!-- DataTables Responsive CSS -->
<link href="/admin/vendor/datatables-responsive/dataTables.responsive.css" rel="stylesheet">
<style type="text/css">
	#AddReturnProductRow .input-style
	{
		width:100%;
	}
</style>
</head>

<body>
    <div id="wrapper">
    	<!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
<?php 
			require_once('../site_header.php');
			require_once('../left_navigation_menu.php');
?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Add Stock Return</h1>
                </div>
                <!-- /.col-lg-12 -->
            </div>
             <form class="form-horizontal" name="AddStockReturn" action="add_stock_return.php" method="post">
            	<div class="panel panel-default">
                    <div class="panel-heading">
                        Enter Stock Returner's Details
                    </div>
                    <div class="panel-body">
<?php
						if ($HasErrors == true)
						{
							echo $NewRecordValidator->DisplayErrors();
						}
?>                    
                    	<!--<div class="form-group">
                    		<label for="IssueType" class="col-lg-2 control-label">Issue Type</label>
                    		<div class="col-lg-4">
	                            <select class="form-control" name="drdIssueType" id="IssueType">
<?php
								foreach ($IssueTypeList as $IssueType => $IssueTypeName)
								{
?>
									<option <?php echo ($Clean['IssueType'] == $IssueType) ? 'selected="selected"' : ''; ?> value="<?php echo $IssueType; ?>"><?php echo $IssueTypeName; ?></option>
<?php
								}
?>
								</select>
							</div>
							<label for="Department" class="col-lg-2 control-label">Department</label>
							<div class="col-lg-4">
								<select class="form-control" name="drdDepartment" id="Department" <?php echo($Clean['IssueType'] == 'Staff') ? 'disabled="disabled"' : ''?> >
<?php
								foreach ($AllDepartmentList as $DepartmentID => $DepartmentName)
								{
?>
									<option <?php echo ($Clean['DepartmentID'] == $DepartmentID) ? 'selected="selected"' : ''; ?> value="<?php echo $DepartmentID; ?>"><?php echo $DepartmentName; ?></option>
<?php
								}
?>
								</select>
							</div>
                        </div>-->
                        <div class="form-group">
	                        <label for="StaffCategory" class="col-lg-2 control-label">Staff Category</label>
	                        <div class="col-lg-4">
	                            <select class="form-control" name="drdStaffCategory" id="StaffCategory">
<?php
                                foreach ($StaffCategoryList as $StaffCategory => $StaffCategoryName)
                                {
?>
                                    <option <?php echo ($StaffCategory == $Clean['StaffCategory'] ? 'selected="selected"' : ''); ?> value="<?php echo $StaffCategory; ?>"><?php echo $StaffCategoryName; ?></option>
<?php
                                }
?>
	                            </select>
	                        </div>
	                        <label for="BranchStaff" class="col-lg-2 control-label">Branch Staff</label>
	                        <div class="col-lg-4">
	                            <select class="form-control"  name="drdBranchStaff" id="BranchStaffID">
<?php
                                foreach ($AllBranchStaffList as $BranchStaffID => $BranchStaffName)
                                {
?>
                                    <option <?php echo ($BranchStaffID == $Clean['BranchStaffID'] ? 'selected="selected"' : ''); ?> value="<?php echo $BranchStaffID; ?>"><?php echo $BranchStaffName['FirstName'] . " ". $BranchStaffName['LastName']; ?></option>
<?php
                                }
?>
	                            </select>
	                        </div>
	                    </div>
	                    <div class="form-group">
	                        <div class="col-sm-offset-3 col-lg-10">
	                        	<input type="hidden" name="hdnProcess" value="7" />
								<button type="submit" class="btn btn-primary" >Search</button>
	                        </div>
	                    </div>
                    </div>
                </div>
            </form>
<?php
		if ($Clean['Process'] == 7 && $HasErrors === false) 
		{
?>
		<div class="row">
			<div class="col-lg-12">
				<div class="panel panel-default">
					<!-- /.panel-heading -->
					<div class="panel-heading">
                        Enter Return Stock Details
                    </div>
					<div class="panel-body">
						<form class="form-horizontal" name="StockReturn" action="add_stock_return.php" method="post">
							<div class="row" id="RecordTable">
								<div class="col-lg-12">
									<table width="100%" class="table table-striped table-bordered table-hover" id="DataTableRecords">
										<thead>
											<tr>
												<th>Product Category</th>
												<th>Product Name</th>
												<th>Remaining Quantity</th>
												<th>Issue Date</th>
												<th>Return Date</th>
												<th>Returned Quantity</th>
												<th>Action</th>
											</tr>
										</thead>
										<tbody>
<?php
									if (is_array($AllIssuedStock) && count($AllIssuedStock) > 0)
									{
										$Counter = 0;
										foreach ($AllIssuedStock as $StockIssueID => $IssuedStockDetails)
										{
?>
											<tr>										
												<td><?php echo $IssuedStockDetails['ProductCategoryName']; ?></td>
												<td>
													<?php echo $IssuedStockDetails['ProductName']; ?>
													<input class="form-control" type="hidden" id="ProductID<?php  echo $StockIssueID; ?>" name="StockReturnDetailsRow[<?php  echo $StockIssueID; ?>][ProductID]" value="<?php echo $IssuedStockDetails['ProductID']; ?>"/>
												</td>
												<td><?php echo $IssuedStockDetails['RemaingQuantity']; ?></td>
												<td>
													<?php echo date('d/m/Y', strtotime($IssuedStockDetails['IssueDate'])); ?>
													<input class="form-control" type="hidden" id="IssueDate<?php  echo $StockIssueID; ?>" name="StockReturnDetailsRow[<?php  echo $StockIssueID; ?>][IssueDate]" value="<?php echo $IssuedStockDetails['IssueDate']; ?>"/>
												</td>
												<td><input class="form-control dtepicker" type="text" id="ReturnDate<?php  echo $StockIssueID; ?>" name="StockReturnDetailsRow[<?php  echo $StockIssueID; ?>][ReturnDate]" value="<?php echo date('d/m/Y', strtotime($IssuedStockDetails['ReturnDate'])); ?>"/></td>
												<td><input class="form-control" type="text" id="ReturnQuantity<?php  echo $StockIssueID; ?>" name="StockReturnDetailsRow[<?php  echo $StockIssueID; ?>][ReturnQuantity]" value="<?php echo $IssuedStockDetails['RemaingQuantity']; ?>"/></td>
												<td><button type="button" class="btn btn-danger RemoveRow" style="margin-right: 2%;"> <span class="icon icon-remove">X</span></button></td>
											</tr>
<?php
										}
									}
?>
										</tbody>
									</table>
									<div class="form-group">
										<div class="col-sm-offset-10 col-lg-2">
											<input type="hidden" name="hdnProcess" value="1" />
											<input type="hidden" name="IssueType" value="<?php echo $Clean['IssueType']; ?>" />
											<input type="hidden" name="DepartmentID" value='<?php echo $Clean['DepartmentID'];?>'/>
											<input type="hidden" name="BranchStaffID" value="<?php echo $Clean['BranchStaffID'];?>" />
											<button type="submit" class="btn btn-primary">Return</button>
										</div>
									</div>
								</div>
							</div>
						</form>
						<!-- /.table-responsive -->
					</div>
					<!-- /.panel-body -->
				</div>
				<!-- /.panel -->
			</div>
		</div>
<?php
		} 
?>
        <!-- /#page-wrapper -->
    </div>
    <!-- /#wrapper -->
<?php
require_once('../footer.php');
?>
<!-- DataTables JavaScript -->
<script src="/admin/vendor/datatables/js/jquery.dataTables.min.js"></script>
<script src="/admin/vendor/datatables-plugins/dataTables.bootstrap.min.js"></script>
<script src="/admin/vendor/datatables-responsive/dataTables.responsive.js"></script>
<script src="/admin/vendor/jquery-ui/jquery-ui.min.js"></script>	
<script type="text/javascript">
$(document).ready(function() 
{
	

	GetDatePicker();

	$('body').on("click",'.RemoveRow', function() 
	{
		var TotalTR = $('#DataTableRecords > tbody > tr').length;
		
		if (TotalTR <= 1)
		{
			alert('You can not remove all items.');
			return false;
		}

		var row = $(this).closest("tr");
		var table = row.closest('table').dataTable();
		table.api().row( row ).remove().draw();
		return true;
	});

	$('#DataTableRecords').DataTable({
        responsive: true,
        bPaginate: false,
        bSort: false,
        searching: false, 
        info: false
    });

	/*$('#IssueType').change(function()
	{
		if ($(this).val() == 'Staff') 
		{
			$('#Department').attr('disabled', true);
			$('#StaffCategory').attr('disabled', false);
			$('#BranchStaffID').attr('disabled', false);
			return true;
		}
		else if ($(this).val() == 'Department') 
		{
			$('#Department').attr('disabled', false);
			$('#StaffCategory').attr('disabled', true);
			$('#BranchStaffID').attr('disabled', true);
			return true;
		}
	});*/
	
	$('#StaffCategory').change(function()
	{
		StaffCategory = $(this).val();
		
		if (StaffCategory <= 0)
		{
			$('#BranchStaffID').html('<option value="0">Select Section</option>');
			return;
		}
		
		$.post("/xhttp_calls/get_branch_staff_by_staff_category.php", {SelectedStaffCategory:StaffCategory}, function(data)
		{
		
			ResultArray = data.split("|*****|");
			
			if (ResultArray[0] == 'error')
			{
				alert(ResultArray[1]);
				$('#StaffCategory').val(StaffCategoryBeforeChange);
			}
			else
			{
				$('#BranchStaffID').html(ResultArray[1]);
			}
		 });
	});
});

function GetDatePicker()
{
	$(".dtepicker").datepicker({
        changeMonth: true,
        changeYear: true,
        dateFormat: 'dd/mm/yy'
    });
}
</script>
<!-- JavaScript To Print A Report -->
</body>
</html>