<?php
require_once("../../classes/class.users.php");
require_once('../../classes/class.validation.php');
require_once("../../classes/class.authentication.php");

require_once("../../classes/school_administration/class.subject_master.php");

require_once("../../includes/global_defaults.inc.php");
require_once("../../includes/helpers.inc.php");

//1. RECHECK IF THE USER IS VALID //
try
{
	$AuthObject = new ApplicationAuthentication;
	$LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
catch (Exception $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_LIST_SUBJECT) !== true)
{
	header('location:/admin/unauthorized_login_admin.php');
	exit;
}

$HasErrors = false;

$Clean = array();
$Clean['Process'] = 0;

$Clean['SubjectID'] = 0;

if (isset($_GET['Process']))
{
	$Clean['Process'] = (int) $_GET['Process'];
}
switch ($Clean['Process'])
{
	case 5:
		if ($LoggedUser->HasPermissionForTask(TASK_DELETE_SUBJECT) !== true)
		{
			header('location:/admin/unauthorized_login_admin.php');
			exit;
		}
		
		if (isset($_GET['SubjectID']))
		{
			$Clean['SubjectID'] = (int) $_GET['SubjectID'];
		}
		
		if ($Clean['SubjectID'] <= 0)
		{
			header('location:../error_page.php');
			exit;
		}						
			
		try
		{
			$SubjectMasterToDelete = new SubjectMaster($Clean['SubjectID']);
		}
		catch (ApplicationDBException $e)
		{
			header('location:../error_page.php');
			exit;
		}
		catch (Exception $e)
		{
			header('location:../error_page.php');
			exit;
		}
		
		$RecordValidator = new Validator();
		
		if ($SubjectMasterToDelete->CheckDependencies())
		{
			$RecordValidator->AttachTextError('This subject cannot be deleted. There are dependent records for this subject.');
			$HasErrors = true;
			break;
		}
				
		if (!$SubjectMasterToDelete->Remove())
		{
			$RecordValidator->AttachTextError(ProcessErrors($SubjectMasterToDelete->GetLastErrorCode()));
			$HasErrors = true;
			break;
		}
		
		header('location:subject_master_list.php?Mode=DD');
	break;
}

$AllSubjectMasters = array();
$AllSubjectMasters = SubjectMaster::GetAllSubjectMasters();

require_once('../html_header.php');
?>
<title>Subject Master List</title>
</head>

<body>

    <div id="wrapper">
    	<!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
<?php 
			require_once('../site_header.php');
			require_once('../left_navigation_menu.php');
?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Subject Master List</h1>
                </div>
                <!-- /.col-lg-12 -->
            </div>
            <!-- /.row -->
            <div class="row">
                <div class="col-lg-12">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <strong>Total Records Returned: <?php echo count($AllSubjectMasters); ?></strong>
                        </div>
                        <!-- /.panel-heading -->
                        <div class="panel-body">
                            <div>
                                <div class="row">
                                    <div class="col-lg-6">
                                    <div class="add-new-btn-container"><a href="add_subject_master.php" class="btn btn-primary<?php echo $LoggedUser->HasPermissionForTask(TASK_ADD_SUBJECT) === true ? '' : ' disabled'; ?>" role="button">Add New Subject</a></div>
                                    </div>
                                    <div class="col-lg-6">
                                        <div class="print-btn-container"><button id="PrintButton" type="submit" class="btn btn-primary">Print</button></div>
                                    </div>
                                </div>
<?php
                            if ($HasErrors == true)
                            {
                                echo $RecordValidator->DisplayErrorsInTable();
                            }
?>
                                <div class="row" id="RecordTableHeading">
                                    <div class="col-lg-12">
                                    	<div class="report-heading-container"><strong>Subject Master List on <?php echo date('d-m-Y h:i A'); ?></strong></div>
                                    </div>
								</div>
                                <div class="row" id="RecordTable">
                                    <div class="col-lg-12">
                                        <table width="100%" class="table table-striped table-bordered table-hover">
                                            <thead>
                                                <tr>
                                                    <th>S. No</th>
                                                    <th>Subject</th>
                                                    <th>Is Active</th>
                                                    <th>Create User</th>
                                                    <th>Create Date</th>
                                                    <th class="print-hidden">Operations</th>
                                                </tr>
                                            </thead>
                                            <tbody>
    <?php
                                    if (is_array($AllSubjectMasters) && count($AllSubjectMasters) > 0)
                                    {
                                        $Counter = 0;
                                        foreach ($AllSubjectMasters as $SubjectID => $SubjectMastersDetails)
                                        {
    ?>
                                                <tr>
                                                    <td><?php echo ++$Counter; ?></td>
                                                    <td><?php echo $SubjectMastersDetails['Subject']; ?></td>
                                                    <td><?php echo (($SubjectMastersDetails['IsActive']) ? 'Yes' : 'No'); ?></td>
                                                    <td><?php echo $SubjectMastersDetails['CreateUserName']; ?></td>
                                                    <td><?php echo date('d/m/Y', strtotime($SubjectMastersDetails['CreateDate'])); ?></td>
                                                    <td class="print-hidden">
<?php
													if ($LoggedUser->HasPermissionForTask(TASK_EDIT_SUBJECT) === true)
													{
														echo '<a href="edit_subject_master.php?Process=2&amp;SubjectID='.$SubjectID.'">Edit</a>';
													}
													else
													{
														echo 'Edit';
													}

													echo '&nbsp;|&nbsp;';

													if ($LoggedUser->HasPermissionForTask(TASK_DELETE_SUBJECT) === true)
													{
														echo '<a class="delete-record" href="subject_master_list.php?Process=5&amp;SubjectID='.$SubjectID.'">Delete</a>'; 
													}
													else
													{
														echo 'Delete';
													}
?>
                                                        </td>
                                                </tr>
    <?php
                                        }
                                    }
                                    else
                                    {
    ?>
                                                <tr>
                                                    <td colspan="6">No Records</td>
                                                </tr>
    <?php
                                    }
    ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                            <!-- /.table-responsive -->
                        </div>
                        <!-- /.panel-body -->
                    </div>
                    <!-- /.panel -->
                </div>
                <!-- /.col-lg-12 -->
            </div>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
<?php
require_once('../footer.php');
if (PrintMessage($_GET, $Message))
{
?>
    <script type="text/javascript">
        alert('<?php echo $Message; ?>');
    </script>
<?php
}
?>	
<script type="text/javascript">
$(document).ready(function() {
	$(".delete-record").click(function()
    {	
        if (!confirm("Are you sure you want to delete this Subject?"))
        {
            return false;
        }
    });
});
</script>
	<!-- JavaScript To Print A Report -->
    <script src="js/print-report.js"></script>
</body>
</html>